package com.lantone.dblayermbg.facade;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.lantone.common.dto.OperationLogDTO;
import com.lantone.common.vo.GetOperationLogVO;
import com.lantone.dblayermbg.entity.OperationLog;
import com.lantone.dblayermbg.mapper.OperationLogMapper;
import com.lantone.dblayermbg.service.impl.OperationLogServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 * 表名：sys_operation_log 业务类
 * </p>
 */
@Component
public class OperationLogFacade extends OperationLogServiceImpl {
    @Autowired
    private OperationLogMapper operationLogMapper;

    /**
     * @Description: 新增操作日志
     * @Param: [operationLog]
     * @return: void
     * @Author: cy
     * @Date: 2021/9/8
     */
    public void addOperLog(OperationLogDTO operationLog) {
        operationLogMapper.addOperLog(operationLog);
    }

    /**
     * @Description:  查看操作日志
     * @Param: [getOperationLogVO]
     * @return: com.baomidou.mybatisplus.core.metadata.IPage<com.lantone.common.dto.OperationLogDTO>
     * @Author: cy
     * @Date: 2021/9/8
     */
    public IPage<OperationLogDTO> getOperationLog(GetOperationLogVO getOperationLogVO) {
        return operationLogMapper.getOperationLog(getOperationLogVO);
    }

    /**
     * @Description:  查看操作日志操作用户
     * @Param: [operationName]
     * @return: java.util.List<java.lang.String>
     * @Author: cy
     * @Date: 2021/9/8
     */
    public List<String> getOperationLogName(String operationName) {
        return this.lambdaQuery()
                .like(StringUtils.isNotBlank(operationName), OperationLog::getOperationName, operationName)
                .select(OperationLog::getOperationName)
                .list().stream().map(OperationLog::getOperationName).collect(Collectors.toList());
    }
}