package com.lantone.report.aggregate;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.google.common.collect.Lists;
import com.lantone.common.dto.report.ReBeHosDTO;
import com.lantone.common.dto.report.ReBeHosDetailDTO;
import com.lantone.common.dto.report.ReBeHosMergeDTO;
import com.lantone.common.util.ListUtil;
import com.lantone.common.vo.report.FilterVO;
import com.lantone.common.vo.report.ReBeHosPageVO;
import com.lantone.dblayermbg.facade.report.BehospitalInfoFacade;
import com.lantone.report.facade.FilterFacade;
import io.github.lvyahui8.spring.annotation.DataConsumer;
import io.github.lvyahui8.spring.annotation.DataProvider;
import io.github.lvyahui8.spring.annotation.InvokeParameter;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2020/7/15 16:03
 */
@Component
public class LeaveHosStatisticsAggregate {
    @Autowired
    private BehospitalInfoFacade behospitalInfoFacade;
    @Autowired
    private FilterFacade filterFacade;

    @DataProvider("setAllLeaveHos")
    public Map<String, Object> setAllLeaveHos(
            @InvokeParameter("filterVO") FilterVO filterVO,
            @DataConsumer("getTotleCount") Integer totleNum,
            @DataConsumer("getDeathCount") Integer deathNum,
            @DataConsumer("getNewBornCount") Integer newBornNum,
            @DataConsumer("getOperationCount") Integer operationNum,
            @DataConsumer("getNonAdviceCount") Integer nonAdviceNum,
            @DataConsumer("get31DaysBehospitalCount") Integer reBehospitalNum) {

        Map<String, Object> retMap = new LinkedHashMap<>();
        retMap.put("总人数", totleNum);
        retMap.put("死亡人数", deathNum);
        retMap.put("新生儿人数", newBornNum);
        retMap.put("手术病人数", operationNum);
        retMap.put("非医嘱离院病人数", nonAdviceNum);
        retMap.put("31日再入院病历数", reBehospitalNum);
        return retMap;

    }
    /**
     * 总人数
     *
     * @param filterVO
     * @return
     */
    @DataProvider("getTotleCount")
    public Integer getTotleCount(@InvokeParameter("filterVO") FilterVO filterVO) {
        return behospitalInfoFacade.getBaseMapper().leaveHosCount(filterVO);
    }

    /**
     * 死亡人数
     *
     * @param filterVO
     * @return
     */
    @DataProvider("getDeathCount")
    public Integer getDeathCount(@InvokeParameter("filterVO") FilterVO filterVO) {
        return behospitalInfoFacade.getBaseMapper().deathCount(filterVO);
    }

    /**
     * 新生儿患者人数
     *
     * @param filterVO
     * @return
     */
    @DataProvider("getNewBornCount")
    public Integer getNewBornCount(@InvokeParameter("filterVO") FilterVO filterVO) {
        return behospitalInfoFacade.getBaseMapper().newBornCount(filterVO);
    }

    /**
     * 手术人数
     *
     * @param filterVO
     * @return
     */
    @DataProvider("getOperationCount")
    public Integer getOperationCount(@InvokeParameter("filterVO") FilterVO filterVO) {
        return behospitalInfoFacade.getBaseMapper().operationCount(filterVO);
    }

    /**
     * 非医嘱离院
     *
     * @param filterVO
     * @return
     */
    @DataProvider("getNonAdviceCount")
    public Integer getNonAdviceCount(@InvokeParameter("filterVO") FilterVO filterVO) {
        return behospitalInfoFacade.getBaseMapper().nonAdviceCount(filterVO);
    }

    /**
     * 31天重复入院
     *
     * @param filterVO
     * @return
     */
    @DataProvider("get31DaysBehospitalCount")
    public Integer get31DaysBehospitalCount(@InvokeParameter("filterVO") FilterVO filterVO) {
        ReBeHosPageVO reBeHosPageVO = new ReBeHosPageVO();
        BeanUtil.copyProperties(filterVO,reBeHosPageVO);
        reBeHosPageVO.setStartDate(timeTrans(filterVO.getStartDate()));
        reBeHosPageVO.setEndDate(timeTrans(filterVO.getEndDate()));
        reBeHosPageVO.setFlag(31);
        IPage<ReBeHosDTO> reBeHosDTOIPage = reHos31DaysPage(reBeHosPageVO);
        List<ReBeHosDTO> records = reBeHosDTOIPage.getRecords();
        Set<String> codeList = new HashSet<>();
        records.forEach(obj->{
            obj.getDetails().forEach(opj->{
                codeList.add(opj.getBehospitalCode());
            });
        });
        return codeList.size();
    }

    /**
     * 31天再入院详情页
     *
     * @param reBeHosPageVO
     * @return
     */
    public IPage<ReBeHosDTO> reHos31DaysPage(ReBeHosPageVO reBeHosPageVO) {
        filterFacade.reBeHosPageVOSet(reBeHosPageVO);
        long size = reBeHosPageVO.getSize();
        long current = reBeHosPageVO.getCurrent();
        reBeHosPageVO.setCurrent(1L);
        reBeHosPageVO.setSize(Long.MAX_VALUE);
        IPage<ReBeHosMergeDTO> page = behospitalInfoFacade.getBaseMapper().reHos31DaysPage(reBeHosPageVO);
        List<ReBeHosMergeDTO> records = page.getRecords();
        IPage<ReBeHosDTO> retPage = new Page<>();
        if (ListUtil.isNotEmpty(records)) {
            BeanUtil.copyProperties(page, retPage);
            List<ReBeHosDTO> retRecords = Lists.newLinkedList();
            Iterator<ReBeHosMergeDTO> iterator = records.iterator();
            while(iterator.hasNext()){
                ReBeHosMergeDTO record = iterator.next();
                strTrans(record);
                Boolean flag = isContainDiagnose(record);
                if(!flag){
                    iterator.remove();
                    continue;
                }
                ReBeHosDTO retRecord = new ReBeHosDTO();
                BeanUtil.copyProperties(record, retRecord);
                List<ReBeHosDetailDTO> details = Lists.newLinkedList();
                ReBeHosDetailDTO detailRecord = new ReBeHosDetailDTO();
                BeanUtil.copyProperties(record, detailRecord);
                details.add(detailRecord);
                ReBeHosDetailDTO lastDetailRecord = new ReBeHosDetailDTO();
                lastDetailRecord.setName(record.getName());
                lastDetailRecord.setAge(record.getLastAge());
                lastDetailRecord.setDiagnose(record.getLastDiagnose());
                lastDetailRecord.setDiagnoseName(record.getLastDiagnoseName());
                lastDetailRecord.setBehDeptId(record.getLastBehDeptId());
                lastDetailRecord.setBehDeptName(record.getLastBehDeptName());
                lastDetailRecord.setBehospitalCode(record.getLastBehospitalCode());
                lastDetailRecord.setBehospitalDate(record.getLastBehospitalDate());
                lastDetailRecord.setLeaveHospitalDate(record.getLastLeaveHospitalDate());
                lastDetailRecord.setLevel(record.getLastLevel());
                lastDetailRecord.setScoreRes(record.getLastScoreRes());
                lastDetailRecord.setBehospitalDayNum(record.getLastBehospitalDayNum());
                lastDetailRecord.setTotleFee(record.getLastTotleFee());
                details.add(lastDetailRecord);
                retRecord.setDetails(details);
                retRecords.add(retRecord);
            }
            //首页返回全部数据
            if(reBeHosPageVO.getFlag()==31){
                retPage.setRecords(retRecords);
                return retPage;
            }
            //导出操作
            if(reBeHosPageVO.getFlag()==1){
                size = retRecords.size();
            }
            retPage.setSize(size);
            retPage.setTotal(retRecords.size());
            retPage.setCurrent(current);
            //数据返回索引处理
            if(0 == current){
                current = 1;
            }
            int startIndex = ((int)current -1)*10;
            int endIndex = startIndex + (int) size;

            if(retRecords.size()>1){
                if( retRecords.size()-startIndex<(int)size){
                    retRecords = retRecords.subList(startIndex,retRecords.size());
                }else{
                    retRecords = retRecords.subList(startIndex,endIndex );
                }
            }
            retPage.setRecords(retRecords);
        }
        return retPage;
    }

    static Boolean isContainDiagnose(ReBeHosMergeDTO record){
        // String lastDiagnoseName = replace(record.getLastDiagnoseName());本身使用,分隔
        String diagnose =replace(record.getDiagnose());//手动分隔
        String lastDiagnose = replace(record.getLastDiagnose());
        record.setDiagnose(diagnose);
        record.setLastDiagnose(lastDiagnose);
        Set lastDiagnoseNames = strTranListMethod(record.getLastDiagnoseName());
        Set diagnoses = strTranListMethod(record.getDiagnose());
        long count = diagnoses.stream().filter(obj ->null != lastDiagnoseNames && null != obj && lastDiagnoseNames.contains(obj)).count();
        if(count<=0){
            return false;
        }
        return true;
    };


    static Set strTranListMethod(String str){
        Set<String> names = new HashSet<>();
        if(StringUtils.isNotEmpty(str)){
            if(str.contains(",") && str.length()>1){
                for (String diagnoseName : str.split(",")) {
                    names.add(diagnoseName);
                }
            }else{
                names.add(str);
            }
        }
        return names;
    };

    static String replace(String str){
        if(StringUtils.isEmpty(str)){
            return null;
        }
        str = str.trim().replace("；", ",").replace(";", ",")
                .replace("、", ",").replace("，", ",")
                .replace("|", ",").replace(" ", ",")
                .replace(":", ",") .replace("：", ",");
        if(str.startsWith(",")){
            str = str.substring(1);
        }
        if(str.endsWith(",")){
            str = str.substring(0,str.length()-1);
        }

        return str;
    }

    public static Date timeTrans(String time){
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        try {
            Date date = format.parse(time);
            return date;
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return new Date();
    }


    public static void strTrans(ReBeHosMergeDTO record) {
        String replace = record.getLastAgainBehospitalPlan();
        if(StringUtils.isEmpty(replace)){
            replace = "否";
            record.setLastAgainBehospitalPlan(replace);
            return;
        }
        replace = replace.replace("无", "否")
                .replace("-", "无").replace("是一周后", "是")
                .replace("1", "否").replace("2", "是")
                .replace("有", "是");
        record.setLastAgainBehospitalPlan(replace);
    }
}
