package com.lantone.report.facade;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.lantone.common.dto.report.EntryNumDTO;
import com.lantone.common.dto.report.NumDTO;
import com.lantone.common.util.ExcelUtils;
import com.lantone.common.util.ListUtil;
import com.lantone.common.vo.report.FilterPageVO;
import com.lantone.common.vo.report.FilterVO;
import com.lantone.dblayermbg.facade.report.QcresultInfoFacade;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletResponse;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;


@Component
public class EntryCaseManagementFacade {

    @Autowired
    private FilterFacade filterFacade;
    @Autowired
    private QcresultInfoFacade qcresultInfoFacade;

    /**
     * 条目缺陷占比-控制台
     *
     * @param filterVO
     * @return
     */
    public Map<String, Object> entryCountGroupByEntry(FilterVO filterVO) {
        Map<String, Object> retMap = new HashMap<>();
        filterFacade.filterVOSet(filterVO);
        List<NumDTO> entryList = qcresultInfoFacade.getBaseMapper().entryCountGroupByEntry(filterVO);
        if (ListUtil.isNotEmpty(entryList)) {
            retMap.put("条目缺陷占比", entryList);
        }
        return retMap;
    }

    /**
     * 条目缺陷占比-报表
     *
     * @return
     */
    public IPage<EntryNumDTO> entryGroupByEntryInnerPage(@Param("filterPageVO") FilterPageVO filterPageVO) {
        //基础数据
        IPage<EntryNumDTO> entryNumDTOIPage = qcresultInfoFacade.getBaseMapper().entryGroupByEntryInnerPage(filterPageVO);
        List<EntryNumDTO> records = entryNumDTOIPage.getRecords();
        if (CollectionUtils.isEmpty(records)) {
            return entryNumDTOIPage;
        }
        String hospitalId = filterPageVO.getHospitalId();
        //缺陷总数
        Integer sumInteget = qcresultInfoFacade.getBaseMapper().entryGroupByEntrySum(filterPageVO.getHospitalId(), filterPageVO.getIsPlacefile(),
                filterPageVO.getStartDate(), filterPageVO.getEndDate());
        float nsum = 0;
        Set<Long> ids = new HashSet<Long>();
        for (EntryNumDTO record : records) {
            ids.add(record.getId());
            int num = record.getNum().intValue();
            if (sumInteget != null && sumInteget != 0) {
                int sum = sumInteget.intValue();
                nsum = (float) num / sum;
            }
            DecimalFormat df = new DecimalFormat("0.00");
            String percent = df.format(nsum * 100);
            record.setPercentStr(percent + "%");
            record.setTotleNum(sumInteget);
        }
        //缺陷分值
        String isPlacefile = filterPageVO.getIsPlacefile();
        List<EntryNumDTO> entryScore = new ArrayList<>();
        entryScore = qcresultInfoFacade.getBaseMapper().entryGroupByEntryScore(hospitalId, isPlacefile, ids);
        for (EntryNumDTO record : records) {
            for (EntryNumDTO entryNumDTO : entryScore) {
                if (record.getId().equals(entryNumDTO.getId())) {
                    record.setScore(entryNumDTO.getScore());
                }
            }
        }
        return entryNumDTOIPage;
    }

    /**
     * 条目缺陷占比-报表导出
     *
     * @param filterPageVO
     * @return
     */
    public void entryGroupByEntryExport(HttpServletResponse response, FilterPageVO filterPageVO) {
        filterPageVO.setCurrent(1L);
        filterPageVO.setSize(Long.MAX_VALUE);
        filterPageVO.setSearchCount(false);
        filterFacade.filterPageVOSet(filterPageVO);
        IPage<EntryNumDTO> page = this.entryGroupByEntryInnerPage(filterPageVO);
        String fileName = "条目缺陷占比.xls";
        ExcelUtils.exportExcel(page.getRecords(), null, "sheet1", EntryNumDTO.class, fileName, response, 12.8f);
    }
}