package com.lantone.report.web;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.lantone.common.api.CommonResult;
import com.lantone.common.dto.report.QcResultShortDTO;
import com.lantone.common.vo.report.FilterVO;
import com.lantone.common.vo.report.QcResultShortPageVO;
import com.lantone.report.facade.LeaveHospitalManagementFacade;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.Map;


/**
 * <p>
 * 出院管理统计相关API
 * </p>
 *
 * @author zhaops
 * @since 2020-04-27
 */

@RestController
@RequestMapping("/console")
@Api(value = "出院管理统计相关API", tags = { "出院管理统计相关API" })
@SuppressWarnings("unchecked")
public class LeaveHospitalManagementController {
    @Autowired
    private LeaveHospitalManagementFacade leaveHospitalManagementFacade;

    /**
     * 出院人数统计
     *
     * @param filterVO
     * @return
     */
    @ApiOperation(value = "出院人数统计-控制台[by:zhaops]")
    @PostMapping("/leaveHosCount")
    public CommonResult<Map<String, Object>> leaveHosCount(@RequestBody @Valid FilterVO filterVO) {
        return CommonResult.success(leaveHospitalManagementFacade.leaveHosCount(filterVO));
    }

    /**
     * 出院人数统计-报表
     *
     * @param qcResultShortPageVO
     * @return
     */
    @ApiOperation(value = "出院人数统计-报表[by:zhaops]")
    @PostMapping("/leaveHosMRPage")
    public CommonResult<IPage<QcResultShortDTO>> leaveHosMRPage(@RequestBody @Valid QcResultShortPageVO qcResultShortPageVO) {
        return CommonResult.success(leaveHospitalManagementFacade.leaveHosMRPage(qcResultShortPageVO));
    }

    /**
     * 出院人数统计-报表导出
     *
     * @param qcResultShortPageVO
     * @return
     */
    @ApiOperation(value = "出院人数统计-报表导出[by:zhaops]")
    @PostMapping("/leaveHosMrPageExport")
    public void leaveHosMrPageExport(HttpServletResponse response, @RequestBody @Valid QcResultShortPageVO qcResultShortPageVO) {
        leaveHospitalManagementFacade.leaveHosMrPageExportMethod(response, qcResultShortPageVO);
    }
}
