package com.lantone.report.web;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.lantone.common.api.CommonResult;
import com.lantone.common.dto.report.NumDTO;
import com.lantone.common.vo.report.FilterPageVO;
import com.lantone.common.vo.report.FilterVO;
import com.lantone.report.facade.ModuleCaseManagementFacade;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.Map;


/**
 * <p>
 * 模块缺陷管理统计相关API
 * </p>
 *
 * @author zhaops
 * @since 2020-04-27
 */

@RestController
@RequestMapping("/console")
@Api(value = "模块缺陷管理统计相关API", tags = { "模块缺陷管理统计相关API" })
@SuppressWarnings("unchecked")
public class ModuleCaseManagementController {
    @Autowired
    private ModuleCaseManagementFacade moduleCaseManagementFacade;

    /**
     * 各模块缺陷占比排行-控制台
     *
     * @param filterVO
     * @return
     */
    @ApiOperation(value = "各模块缺陷占比排行-控制台[by:zhaops]")
    @PostMapping("/entryCountGroupByCase")
    public CommonResult<Map<String, Object>> entryCountGroupByCase(@RequestBody @Valid FilterVO filterVO) {
        return CommonResult.success(moduleCaseManagementFacade.entryCountGroupByCase(filterVO));
    }

    /**
     * 各模块缺陷占比排行-报表
     *
     * @param filterPageVO
     * @return
     */
    @ApiOperation(value = "各模块缺陷占比排行-报表[by:zhaops]")
    @PostMapping("/entryCountGroupByCasePage")
    public CommonResult<IPage<NumDTO>> entryCountGroupByCasePage(@RequestBody @Valid FilterPageVO filterPageVO) {
        return CommonResult.success(moduleCaseManagementFacade.entryCountGroupByCasePage(filterPageVO));
    }

    /**
     * 各模块缺陷占比排行-报表导出
     *
     * @param filterPageVO
     * @return
     */
    @ApiOperation(value = "各模块缺陷占比排行-报表导出[by:gaodm]")
    @PostMapping("/entryCountGroupByCaseExport")
    public void entryCountGroupByCaseExport(HttpServletResponse response, @RequestBody @Valid FilterPageVO filterPageVO) {
        moduleCaseManagementFacade.entryCountGroupByCaseExport(response, filterPageVO);
    }
}
