package com.lantone.security.facade;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.lantone.common.dto.AbnormalLogDTO;
import com.lantone.common.dto.LoginLogDTO;
import com.lantone.common.dto.OperationLogDTO;
import com.lantone.common.vo.GetAbnormalLogVO;
import com.lantone.common.vo.GetAbnormalWayAndIpVO;
import com.lantone.common.vo.GetLoginLogVO;
import com.lantone.common.vo.GetLoginNameAndIpVO;
import com.lantone.common.vo.GetOperationLogVO;
import com.lantone.dblayermbg.facade.AbnormalLogFacade;
import com.lantone.dblayermbg.facade.LoginLogFacade;
import com.lantone.dblayermbg.facade.OperationLogFacade;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import java.util.List;

/**
 * @Description:日志管理
 * @Author: cy
 * @time: 2021/9/8 10:45
 */
@Component
public class LogManagementFacade {
    @Autowired
    private LoginLogFacade loginLogFacade;
    @Autowired
    private OperationLogFacade operationLogFacade;
    @Autowired
    private AbnormalLogFacade abnormalLogFacade;

    /**
     * @Description: 查看登录日志
     * @Param: [getLoginLogVO]
     * @return: com.baomidou.mybatisplus.core.metadata.IPage<com.lantone.common.dto.LoginLogDTO>
     * @Author: cy
     * @Date: 2021/9/8
     */
    public IPage<LoginLogDTO> getLoginLog(GetLoginLogVO getLoginLogVO) {
        return loginLogFacade.getLoginLog(getLoginLogVO);
    }

    /**查看登录日志登录用户|登录ip地址
     * @Description:
     * @Param: [getLoginNameAndIpVO]
     * @return: java.util.List<java.lang.String>
     * @Author: cy
     * @Date: 2021/9/8
     */
    public List<String> getLoginLogNameAndIp(GetLoginNameAndIpVO getLoginNameAndIpVO) {
        return loginLogFacade.getLoginLogNameAndIp(getLoginNameAndIpVO);
    }

    /**
     * @Description:  查看操作日志
     * @Param: [getOperationLogVO]
     * @return: com.baomidou.mybatisplus.core.metadata.IPage<com.lantone.common.dto.OperationLogDTO>
     * @Author: cy
     * @Date: 2021/9/8
     */
    public IPage<OperationLogDTO> getOperationLog(GetOperationLogVO getOperationLogVO) {
        return operationLogFacade.getOperationLog(getOperationLogVO);
    }

    /**
     * @Description:  查看操作日志操作用户
     * @Param: [operationName]
     * @return: java.util.List<java.lang.String>
     * @Author: cy
     * @Date: 2021/9/8
     */
    public List<String> getOperationLogName(String operationName) {
        return operationLogFacade.getOperationLogName(operationName);
    }

    /**
     * @Description:  查看异常日志
     * @Param: [getAbnormalLogVO]
     * @return: com.baomidou.mybatisplus.core.metadata.IPage<com.lantone.common.dto.AbnormalLogDTO>
     * @Author: cy
     * @Date: 2021/9/8
     */
    public IPage<AbnormalLogDTO> getAbnormalLog(GetAbnormalLogVO getAbnormalLogVO) {
        return  abnormalLogFacade.getAbnormalLog(getAbnormalLogVO);
    }

    /**
     * @Description:  查看异常日志请求方式|ip地址
     * @Param: [getAbnormalWayAndIpVO]
     * @return: java.util.List<java.lang.String>
     * @Author: cy
     * @Date: 2021/9/8
     */
    public List<String> getAbnormalLogWayAndIp(GetAbnormalWayAndIpVO getAbnormalWayAndIpVO) {
        return  abnormalLogFacade.getAbnormalLogWayAndIp(getAbnormalWayAndIpVO);
    }
}
